@@ -34,59 +34,107 @@ Reply createScheduleTask::SchedulePress(semanticAnalysisTask &semanticTask)
     //如果转换失败则返回错误消息
     if (createJsonData == nullptr)
         return errorMessage();
-    //查询日程
     Reply m_reply;
     if (createJsonData->getPropertyStatus() != JsonData::PRO_NONE
             || createJsonData->offset() > -1) {
         REPLY_ONLY_TTS(m_reply, CREATE_ERR_TTS, CREATE_ERR_TTS, true);
         return m_reply;
     }
+    //如果时间无效
+    if (createJsonData->getDateTimeInvalid()) {
+        REPLY_ONLY_TTS(m_reply, DATETIME_ERR_TTS, DATETIME_ERR_TTS, true);
+        return m_reply;
+    }
 
     m_widget = new createSchedulewidget();
     //设置日程时间
     setDateTime(createJsonData);
-    qDebug() << "beginDateTimeIsinHalfYear"
-             << beginDateTimeIsinHalfYear()
-             << "ShouldEndSession"
-             << createJsonData->ShouldEndSession();
-    //判断日程开始时间是否在半年以内
-    if (beginDateTimeIsinHalfYear() || m_begintime.date() == QDate::currentDate()) {
-        //判断多伦标志
-        if (createJsonData->ShouldEndSession()) {
+    if (m_begintime > m_endtime) {
+        //日程的开始时间大于结束时间，
+        qCritical("error: schedule begindatetime is after the enddatetime!");
+    }
+    if (shouldEndSession(createJsonData)) {
+        if (!isValidDateTime) {
+            qInfo() << "schedule begintime or endtime is not valided!";
+            //无效时间，直接返回回复语
+            REPLY_ONLY_TTS(m_reply, replyNotValidDT, replyNotValidDT, true);
+            //设置时间有效标志为true
+            isValidDateTime = true;
+            return m_reply;
+        } else if (!beginDateTimeIsinHalfYear()) {
+            if (beginDateTimeBeforeCurrent()) {
+                qInfo() << "schedule begintime is before currenttime!";
+                //"我现在有点慌，因为我还不会制定过去的提醒"
+                REPLY_ONLY_TTS(m_reply, createJsonData->SuggestMsg(), createJsonData->SuggestMsg(), true);
+            } else if (beginDateTimeOutHalfYear()) {
+                qInfo() << "schedule begintime is after halfyear!";
+                //"只能创建未来半年的日程"
+                REPLY_ONLY_TTS(m_reply, CREATE_TIME_OUT_TTS, CREATE_TIME_OUT_TTS, true);
+            }
+            return m_reply;
+        } else {
             //设置日程titlename
             setScheduleTitleName(createJsonData);
             //创建日程和插件
-            creareScheduleUI(createScheduleWithRepeatStatus(createJsonData));
+            QVector<ScheduleDtailInfo> scheduleinfo = createScheduleWithRepeatStatus(createJsonData);
+            creareScheduleUI(scheduleinfo);
             //带有插件的回复语
             REPLY_WIDGET_TTS(m_reply, m_widget, getReply(createJsonData), getReply(createJsonData), true);
-        } else {
-            //开始date为今天，没有给time(默认为00：00,小于当前time)，需要进行多轮，设置默认回复语
-            //只有回复语
-            REPLY_ONLY_TTS(m_reply, createJsonData->SuggestMsg(), createJsonData->SuggestMsg(), false);
         }
     } else {
-        if (beginDateTimeBeforeCurrent()) {
-            //"我现在有点慌，因为我还不会制定过去的提醒"
-            REPLY_ONLY_TTS(m_reply, createJsonData->SuggestMsg(), createJsonData->SuggestMsg(), true);
-        } else if (beginDateTimeOutHalfYear()) {
-            //"只能创建未来半年的日程"
-            REPLY_ONLY_TTS(m_reply, CREATE_TIME_OUT_TTS, CREATE_TIME_OUT_TTS, true);
-        }
+        //如果需要进行多轮，需要先将此标志设置为true
+        isValidDateTime = true;
+        //开始date为今天，没有给time(默认为00：00,小于当前time)，需要进行多轮，设置默认回复语
+        //只有回复语
+        REPLY_ONLY_TTS(m_reply, createJsonData->SuggestMsg(), createJsonData->SuggestMsg(), false);
     }
-
     return m_reply;
 }
 
 void createScheduleTask::setDateTime(CreateJsonData *createJsonData)
 {
-    if (createJsonData->getDateTime().suggestDatetime.size() > 0) {
-        //用户有输入时间，则设置开始时间
+    //助手返回时间的个数
+    int DateTimeSize = createJsonData->getDateTime().suggestDatetime.size();
+    switch (DateTimeSize) {
+    case 1: {
+        //只有一个时间，为日程开始时间，结束时间为开始时间一个小时后
         m_begintime = createJsonData->getDateTime().suggestDatetime.at(0).datetime;
-        if (!createJsonData->getDateTime().suggestDatetime.at(0).hasTime) {
-            //如果没有time，设置当前time
-            m_begintime.setTime(QTime::currentTime());
+        m_endtime = m_begintime.addSecs(60 * 60);
+        if (!validDateTime(m_begintime)) {
+            //日程时间是否有效
+            QString strDateTime = createJsonData->getDateTime().suggestDatetime.at(0).strDateTime;
+            isValidDateTime = false;
+            replyNotValidDT = QString(ISVALID_DATE_TIME).arg(strDateTime);
+            break;
         }
-        if (createJsonData->getDateTime().suggestDatetime.size() == 2 && m_begintime < QDateTime::currentDateTime()) {
+        if (!createJsonData->getDateTime().suggestDatetime.at(0).hasTime) {
+            m_begintime.setTime(QTime::currentTime());
+            m_endtime = m_begintime.addSecs(60 * 60);
+        }
+    } break;
+    case 2: {
+        //日程是否带有具体时间
+        bool firstScheduleHasTime = createJsonData->getDateTime().suggestDatetime.at(0).hasTime;
+        bool secondScheduleHasTime = createJsonData->getDateTime().suggestDatetime.at(1).hasTime;
+        //有两个时间
+        m_begintime = createJsonData->getDateTime().suggestDatetime.at(0).datetime;
+        m_endtime = createJsonData->getDateTime().suggestDatetime.at(1).datetime;
+        //日程开始时间是否有效
+        if (!validDateTime(m_begintime)) {
+            QString strDateTime = createJsonData->getDateTime().suggestDatetime.at(0).strDateTime;
+            isValidDateTime = false;
+            replyNotValidDT = QString(ISVALID_DATE_TIME).arg(strDateTime);
+            break;
+        }
+        //日程结束时间是否有效
+        if (!validDateTime(m_endtime)) {
+            QString endDateTime = createJsonData->getDateTime().suggestDatetime.at(1).strDateTime;
+            isValidDateTime = false;
+            replyNotValidDT = QString(ISVALID_DATE_TIME).arg(endDateTime);
+            break;
+        }
+        //开始时间为当天的，如果开始日期小于当天不做处理，
+        if (m_begintime.date() == QDateTime::currentDateTime().date()) {
             if (m_begintime.time() > QTime::currentTime()) {
                 //跨天日程，如果日程开始时间大于当前时间，则开始时间为当天
                 m_begintime.setDate(m_begintime.date().addDays(m_begintime.date().daysTo(QDate::currentDate())));
@@ -95,22 +143,21 @@ void createScheduleTask::setDateTime(CreateJsonData *createJsonData)
                 m_begintime.setDate(m_begintime.date().addDays(m_begintime.date().daysTo(QDate::currentDate()) + 1));
             }
         }
-    } else {
-        //用户没有输入时间，则日程开始时间设置为当前时间
-        m_begintime = QDateTime::currentDateTime();
-    }
-    if (createJsonData->getDateTime().suggestDatetime.size() <= 1) {
-        //如果只有开始时间，则结束时间默认为开始时间后一个小时
-        m_endtime = m_begintime.addSecs(60 * 60);
-    } else if (createJsonData->getDateTime().suggestDatetime.size() == 2) {
-        //如果有结束时间，则设置结束时间
-        m_endtime = createJsonData->getDateTime().suggestDatetime.at(1).datetime;
-        if (!createJsonData->getDateTime().suggestDatetime.at(1).hasTime) {
-            //如果用户没有输入结束时间，则默认为当天23：59：59
-            m_endtime.setTime(QTime(23, 59, 59));
+        //开始时间没有具体时间点，设置为当前时间点
+        if (firstScheduleHasTime && !secondScheduleHasTime) {
+            m_endtime.setTime(m_begintime.time());
+        } else if (!firstScheduleHasTime && secondScheduleHasTime) {
+            m_begintime.setTime(m_endtime.time());
         }
+    } break;
+    default: {
+        //其他情况视为错误输入
+        isValidDateTime = false;
+        replyNotValidDT = "您输入的时间不正确，请重新输入";
+    } break;
     }
-    qDebug() << "m_begintime = " << m_begintime << ", m_endtime = " << m_endtime;
+    qInfo() << "scheduleBeginTime: " << m_begintime
+            << "scheduleEndTime: " << m_endtime;
 }
 
 void createScheduleTask::setScheduleTitleName(CreateJsonData *createJsonData)
@@ -133,8 +180,9 @@ QVector<ScheduleDtailInfo> createScheduleTask::createScheduleWithRepeatStatus(Cr
     switch (createJsonData->getRepeatStatus()) {
     case CreateJsonData::NONE: {
         //非重复日程，不能创建过期日程
-        if (m_begintime > QDateTime::currentDateTime() && m_begintime < QDateTime::currentDateTime().addMonths(6))
+        if (m_begintime >= QDateTime::currentDateTime() && m_begintime < QDateTime::currentDateTime().addMonths(6)) {
             schedule = getNotRepeatDaySchedule();
+        }
     }
     break;
     case CreateJsonData::EVED:
@@ -173,11 +221,6 @@ QVector<ScheduleDtailInfo> createScheduleTask::createScheduleWithRepeatStatus(Cr
 void createScheduleTask::creareScheduleUI(QVector<ScheduleDtailInfo> schedule)
 {
     if (!schedule.isEmpty()) {
-        //日程信息不为空，创建插件
-        qDebug() << "creatUI"
-                 << getFirstSchedule(schedule).beginDateTime
-                 << getFirstSchedule(schedule).endDateTime
-                 << m_begintime.daysTo(m_endtime);
         //设置日程时间
         setDateTimeAndGetSchedule(getFirstSchedule(schedule).beginDateTime, getFirstSchedule(schedule).endDateTime);
         //设置dbus
@@ -185,6 +228,8 @@ void createScheduleTask::creareScheduleUI(QVector<ScheduleDtailInfo> schedule)
         m_widget->scheduleEmpty(true);
         //更新界面
         m_widget->updateUI();
+    } else {
+        qCritical("Creat ScheduleInfo is Empty!");
     }
 }
 
@@ -193,10 +238,12 @@ QString createScheduleTask::getReply(CreateJsonData *createJsonData)
     QString str_reply;
     //为特殊情况拼接回复语
     if (createJsonData->getRepeatStatus() == CreateJsonData::RESTD
+            && createJsonData->getDateTime().suggestDatetime.size() > 0
             && createJsonData->getDateTime().suggestDatetime.at(0).hasTime) {
         //如果为休息日，并且有开始时间，拼接回复语
         str_reply = QString(EVERY_WEEKEND_TTS).arg(m_begintime.toString("hh:mm"));
     } else if (createJsonData->getRepeatStatus() == CreateJsonData::NONE
+               && createJsonData->getDateTime().suggestDatetime.size() > 0
                && createJsonData->getDateTime().suggestDatetime.at(0).hasTime
                && createJsonData->getDateTime().suggestDatetime.at(0).datetime < QDateTime::currentDateTime()
                && createJsonData->getDateTime().suggestDatetime.size() == 2
@@ -244,9 +291,10 @@ QVector<ScheduleDtailInfo> createScheduleTask::getNotRepeatDaySchedule()
     //设置重复类型
     m_widget->setRpeat(0);
     //创建日程
-    m_dbus->CreateJob(setDateTimeAndGetSchedule(m_begintime, m_endtime));
+    ScheduleDtailInfo scheduleinfo = setDateTimeAndGetSchedule(m_begintime, m_endtime);
+    m_dbus->CreateJob(scheduleinfo);
     //将所有日程添加到日程容器中
-    schedule.append(setDateTimeAndGetSchedule(m_begintime, m_endtime));
+    schedule.append(scheduleinfo);
 
     return schedule;
 }
@@ -256,10 +304,11 @@ QVector<ScheduleDtailInfo> createScheduleTask::getEveryDaySchedule()
     QVector<ScheduleDtailInfo> schedule;
     //设置重复类型
     m_widget->setRpeat(1);
+    ScheduleDtailInfo scheduleinfo = setDateTimeAndGetSchedule(m_begintime, m_endtime);
     //创建日程
-    m_dbus->CreateJob(setDateTimeAndGetSchedule(m_begintime, m_endtime));
+    m_dbus->CreateJob(scheduleinfo);
     //将所有日程添加到日程容器中
-    schedule.append(setDateTimeAndGetSchedule(m_begintime, m_endtime));
+    schedule.append(scheduleinfo);
     //设置完成后，将everyDayState设置为false
     everyDayState = false;
 
@@ -270,13 +319,13 @@ QVector<ScheduleDtailInfo> createScheduleTask::getEveryWeekSchedule(QVector<int>
 {
     QVector<QDateTime> beginDateTime {};
     QVector<ScheduleDtailInfo> schedule;
-    //每天重复
-    if (everyDayState)
-        return getEveryDaySchedule();
     //设置重复类型
     m_widget->setRpeat(3);
     //获取解析时间
     beginDateTime = analysisEveryWeekDate(dateRange);
+    //每天重复
+    if (everyDayState)
+        return getEveryDaySchedule();
 
     for (int i = 0; i < beginDateTime.count(); i++) {
         //设置日程结束时间
@@ -294,13 +343,13 @@ QVector<ScheduleDtailInfo> createScheduleTask::getEveryMonthSchedule(QVector<int
 {
     QVector<QDateTime> beginDateTime {};
     QVector<ScheduleDtailInfo> schedule;
-    //每天重复
-    if (everyDayState)
-        return getEveryDaySchedule();
     //设置重复类型
     m_widget->setRpeat(4);
     //获取解析日期
     beginDateTime = analysisEveryMonthDate(dateRange);
+    //每天重复
+    if (everyDayState)
+        return getEveryDaySchedule();
 
     for (int i = 0; i < beginDateTime.count(); i++) {
         //设置日程结束时间
@@ -453,7 +502,7 @@ QVector<QDateTime> createScheduleTask::getTwoWeekNumDate(int firstWeekNum, int s
             return beginDateTime;
         } else {
             //除去每天的其他情况
-            firstWeekNumGreaterThanSecondButEveryDay(firstWeekNum, secondWeekNum);
+            beginDateTime = firstWeekNumGreaterThanSecondButEveryDay(firstWeekNum, secondWeekNum);
         }
     }
 
@@ -507,7 +556,7 @@ QVector<QDateTime> createScheduleTask::firstWeekNumGreaterThanSecondButEveryDay(
         }
     } else if (currentDayofWeek < firstWeekNum && currentDayofWeek > secondWeekNum) {
         //今天所在周数小于开始周数，大于结束周数
-        beginDateTime.append(getWeekAllDateTime(QDate::currentDate().addDays(firstWeekNum - currentDayofWeek),firstWeekNum, 7));
+        beginDateTime.append(getWeekAllDateTime(QDate::currentDate().addDays(firstWeekNum - currentDayofWeek), firstWeekNum, 7));
         beginDateTime.append(getWeekAllDateTime(QDate::currentDate().addDays(1 + 7 - currentDayofWeek), 1, secondWeekNum));
     } else if (currentDayofWeek <= secondWeekNum) {
         //今天所在周数小于等于结束周数
@@ -591,7 +640,7 @@ QVector<QDateTime> createScheduleTask::analysisWorkDayDate()
 QDate createScheduleTask::getValidDate(QDate viewDate, int viewDateDay)
 {
     //设置一个无效时间
-    QDate validDate(QDate(0,0,0));
+    QDate validDate(QDate(0, 0, 0));
     //初始化年
     int month = viewDate.month();
     //判断未来半年的时间是否合法
@@ -608,6 +657,25 @@ QDate createScheduleTask::getValidDate(QDate viewDate, int viewDateDay)
     return validDate;
 }
 
+/**
+ * @brief createScheduleTask::shouldEndSession 是否需要进行多轮
+ * @return
+ */
+bool createScheduleTask::shouldEndSession(CreateJsonData *createjsondate)
+{
+    return createjsondate->ShouldEndSession();
+}
+
+/**
+ * @brief createScheduleTask::validDateTime 是否是有效时间
+ * @param datetime 查询的时间
+ * @return
+ */
+bool createScheduleTask::validDateTime(QDateTime datetime)
+{
+    return datetime.isValid();
+}
+
 QVector<QDateTime> createScheduleTask::analysisEveryWeekDate(QVector<int> dateRange)
 {
     QVector<QDateTime> beginDateTime {};
@@ -683,13 +751,13 @@ QVector<QDateTime> createScheduleTask::getOneMonthNumDate(int firstMonthNum)
     if (currentDayofMonth < firstMonthNum) {
         //今天小于开始日期
         //获取合法日期
-        QDate validDate = getValidDate(QDate::currentDate(),firstMonthNum);
+        QDate validDate = getValidDate(QDate::currentDate(), firstMonthNum);
         //日期合法，设置日期
         if (validDate.isValid())
             m_begintime.setDate(validDate);
     } else if (currentDayofMonth > firstMonthNum) {
         //获取合法日期
-        QDate validDate = getValidDate(QDate::currentDate().addMonths(1),firstMonthNum);
+        QDate validDate = getValidDate(QDate::currentDate().addMonths(1), firstMonthNum);
         //日期合法，设置日期
         if (validDate.isValid())
             m_begintime.setDate(validDate);
@@ -714,7 +782,7 @@ QVector<QDateTime> createScheduleTask::getTwoMonthNumDate(int firstMonthNum, int
 
     if (firstMonthNum == secondMonthNum) {
         //开始日期等于结束日期，为每天
-        getEveryDaySchedule();
+        everyDayState = true;
         return beginDateTime;
     } else if (firstMonthNum < secondMonthNum) {
         //开始日期小于结束日期
@@ -723,7 +791,7 @@ QVector<QDateTime> createScheduleTask::getTwoMonthNumDate(int firstMonthNum, int
         //开始日期大于结束日期
         if (firstMonthNum - secondMonthNum == 1) {
             //开始日期和结束日期差一天，为每天
-            getEveryDaySchedule();
+            everyDayState = true;
             return beginDateTime;
         } else {
             //开始日期大于结束日期的其他情况
@@ -784,7 +852,7 @@ QVector<QDateTime> createScheduleTask::getMonthFrontPartDateTime(QDate BeginDate
     int currentDayofMonth = QDate::currentDate().day();
     //包含今天
     if (containsToday)
-        currentDayofMonth +=1;
+        currentDayofMonth += 1;
     //设置日期
     for (int i = firstMonthNum; i < currentDayofMonth; i++) {
         //获取合法日期
@@ -805,7 +873,7 @@ QVector<QDateTime> createScheduleTask::getMonthBackPartDateTime(QDate BeginDate,
     int currentDayofMonth = QDate::currentDate().day();
     //不包含今天
     if (!containsToday)
-        currentDayofMonth +=1;
+        currentDayofMonth += 1;
     //设置日期
     for (int i = currentDayofMonth; i < secondMonthNum + 1; i++) {
         //获取合法日期
